==> hudi-0.14.1.src.tgz: hudi-0.14.1/hudi-spark-datasource/hudi-spark3.0.x/src/main/scala/org/apache/spark/sql/execution/datasources/HoodieSpark30PartitionedFileUtils.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.spark.sql.execution.datasources

import org.apache.hadoop.fs.Path
import org.apache.spark.sql.catalyst.InternalRow

/**
 * Utils on Spark [[PartitionedFile]] for Spark 3.0.
 */
object HoodieSpark30PartitionedFileUtils extends HoodieSparkPartitionedFileUtils {
  override def getPathFromPartitionedFile(partitionedFile: PartitionedFile): Path = {
    new Path(partitionedFile.filePath)
  }

  override def getStringPathFromPartitionedFile(partitionedFile: PartitionedFile): String = {
    partitionedFile.filePath
  }

  override def createPartitionedFile(partitionValues: InternalRow,
                                     filePath: Path,
                                     start: Long,
                                     length: Long): PartitionedFile = {
    PartitionedFile(partitionValues, filePath.toUri.toString, start, length)
  }
}

==> hudi-0.15.0.src.tgz: hudi-0.15.0/hudi-spark-datasource/hudi-spark3.0.x/src/main/scala/org/apache/spark/sql/execution/datasources/HoodieSpark30PartitionedFileUtils.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.spark.sql.execution.datasources

import org.apache.hudi.storage.StoragePath

import org.apache.hadoop.fs.FileStatus
import org.apache.spark.sql.catalyst.InternalRow

/**
 * Utils on Spark [[PartitionedFile]] and [[PartitionDirectory]] for Spark 3.0.
 */
object HoodieSpark30PartitionedFileUtils extends HoodieSparkPartitionedFileUtils {
  override def getPathFromPartitionedFile(partitionedFile: PartitionedFile): StoragePath = {
    new StoragePath(partitionedFile.filePath)
  }

  override def getStringPathFromPartitionedFile(partitionedFile: PartitionedFile): String = {
    partitionedFile.filePath
  }

  override def createPartitionedFile(partitionValues: InternalRow,
                                     filePath: StoragePath,
                                     start: Long,
                                     length: Long): PartitionedFile = {
    PartitionedFile(partitionValues, filePath.toUri.toString, start, length)
  }

  override def toFileStatuses(partitionDirs: Seq[PartitionDirectory]): Seq[FileStatus] = {
    partitionDirs.flatMap(_.files)
  }

  override def newPartitionDirectory(internalRow: InternalRow, statuses: Seq[FileStatus]): PartitionDirectory = {
    PartitionDirectory(internalRow, statuses)
  }
}
